BASE_SUBMITTER_URL = "https://guanaco-submitter.chai-research.com"
BASE_FEEDBACK_URL = "https://guanaco-feedback.chai-research.com"

LEADERBOARD_ENDPOINT = "/leaderboard"
CHAT_ENDPOINT = "/models/{submission_id}/chat"
FEEDBACK_ENDPOINT = "/feedback/{submission_id}"

SUBMISSION_ENDPOINT = "/models/submit"
BLEND_SUBMISSION_ENDPOINT = "/models/submit_blend"
ALL_SUBMISSION_STATUS_ENDPOINT = "/models/"
INFO_ENDPOINT = "/models/{submission_id}"
DEACTIVATE_ENDPOINT = "/models/{submission_id}/deactivate"
REDEPLOY_ENDPOINT = "/models/{submission_id}/redeploy"
EVALUATE_ENDPOINT = "/models/{submission_id}/evaluate"
TEARDOWN_ENDPOINT = "/models/{submission_id}/teardown"

COMPETITIONS_ENDPOINT = '/competitions'
PENDING_COMPETITION_ENDPOINT = '/pending_competition'
ACTIVE_COMPETITION_ENDPOINT = '/active_competition'
